SnapLlcFrame

Struct SnapLlcFrame 

pub struct SnapLlcFrame<'a, Payload = &'a [u8]> {
    pub oui: [u8; 3],
    pub ether_type: EtherType,
    pub payload: Payload,
    pub _phantom: PhantomData<&'a ()>,
}
An unnumbered LLC frame, with the SNAP extension.

Structure

This struct represents an unnumbered LLC frame with a SNAP header. This means, that DSAP and SSAP are equal to 0xaa. It is also expected, that the first two bits of the control field are set to one. If any of these assumptions aren’t met, an error will be returned.

Fields

oui: [u8; 3]

The organizationally unique identifier.

In most cases this is just all zeroes.

ether_type: EtherType

The type of the protocol carried in Self::payload.

NOTE: If the oui isn’t all zeroes, this isn’t actually an ether type. However this is quite uncommon, and an ether type is usually correct. If this isn’t the case, use self.ether_type.into_bits() to get the raw u16 protocol ID.

payload: Payload

The payload of the LLC frame.

_phantom: PhantomData<&'a ()>