pub struct SnapLlcFrame<'a, Payload = &'a [u8]> {
pub oui: [u8; 3],
pub ether_type: EtherType,
pub payload: Payload,
pub _phantom: PhantomData<&'a ()>,
}Expand description
An unnumbered LLC frame, with the SNAP extension.
Structure
This struct represents an unnumbered LLC frame with a SNAP header.
This means, that DSAP and SSAP are equal to 0xaa.
It is also expected, that the first two bits of the control field are set to one.
If any of these assumptions aren’t met, an error will be returned.
Fields
oui: [u8; 3]The organizationally unique identifier.
In most cases this is just all zeroes.
ether_type: EtherTypeThe type of the protocol carried in Self::payload.
NOTE: If the oui isn’t all zeroes, this isn’t actually an ether type.
However this is quite uncommon, and an ether type is usually correct.
If this isn’t the case, use self.ether_type.into_bits() to get the raw u16 protocol ID.
payload: PayloadThe payload of the LLC frame.
_phantom: PhantomData<&'a ()>Trait Implementations
Sourceimpl<'a, Payload: Clone> Clone for SnapLlcFrame<'a, Payload>
impl<'a, Payload: Clone> Clone for SnapLlcFrame<'a, Payload>
Sourcefn clone(&self) -> SnapLlcFrame<'a, Payload>
fn clone(&self) -> SnapLlcFrame<'a, Payload>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, Payload: Debug> Debug for SnapLlcFrame<'a, Payload>
impl<'a, Payload: Debug> Debug for SnapLlcFrame<'a, Payload>
Sourceimpl<'a, Payload: Default> Default for SnapLlcFrame<'a, Payload>
impl<'a, Payload: Default> Default for SnapLlcFrame<'a, Payload>
Sourcefn default() -> SnapLlcFrame<'a, Payload>
fn default() -> SnapLlcFrame<'a, Payload>
Returns the “default value” for a type. Read more
Sourceimpl<Payload: MeasureWith<()>> MeasureWith<()> for SnapLlcFrame<'_, Payload>
impl<Payload: MeasureWith<()>> MeasureWith<()> for SnapLlcFrame<'_, Payload>
Sourcefn measure_with(&self, ctx: &()) -> usize
fn measure_with(&self, ctx: &()) -> usize
How large is
Self, given the ctx?Sourceimpl<'a, Payload: PartialEq> PartialEq for SnapLlcFrame<'a, Payload>
impl<'a, Payload: PartialEq> PartialEq for SnapLlcFrame<'a, Payload>
Sourceimpl<'a> TryFromCtx<'a> for SnapLlcFrame<'a>
impl<'a> TryFromCtx<'a> for SnapLlcFrame<'a>
Sourceimpl<Payload: TryIntoCtx<Error = Error>> TryIntoCtx for SnapLlcFrame<'_, Payload>
impl<Payload: TryIntoCtx<Error = Error>> TryIntoCtx for SnapLlcFrame<'_, Payload>
impl<'a, Payload: Copy> Copy for SnapLlcFrame<'a, Payload>
impl<'a, Payload: Eq> Eq for SnapLlcFrame<'a, Payload>
impl<'a, Payload> StructuralPartialEq for SnapLlcFrame<'a, Payload>